@@ -4,8 +4,6 @@
         stop(paste("Package lme4 conflicts with package nlme.\n",
                    "To attach lme4 you must restart R without package nlme."))
     }
-    require("methods", quietly = TRUE)
-    require("Matrix", quietly = TRUE)
 }
 
 setOldClass("data.frame")
@@ -39,14 +37,6 @@ setClass("VarCorr",
                         useScale="logical"),
          prototype = list(scale = 1.0, useScale = TRUE))
 
-setClass("groupedData",
-         representation(data = "data.frame",
-                        formula = "formula",
-                        outer = "formula",
-                        inner = "formula",
-                        labels = "list",
-                        units = "list"))
-
 setClass("summary.ssclme",
          representation(coefficients="matrix",
                         scale="numeric",
