@@ -52,7 +52,7 @@ lmeControl <-                            # Control parameters for lme
            niterEM = 20,
            msTol = sqrt(.Machine$double.eps),
            msScale,
-           msVerbose = getOption("verbose"),
+           msVerbose = as.integer(getOption("verbose")),
            PQLmaxIt = 20,
            .relStep = (.Machine$double.eps)^(1/3),
            nlmStepMax = NULL,
@@ -104,21 +104,6 @@ setMethod("lme", signature(formula = "missing"),
                 mCall, PACKAGE = "Matrix")
       })
 
-setMethod("lme", signature(formula = "formula", data = "groupedData",
-                           random = "missing"),
-          function(formula, data, random,
-                   method = c("REML", "ML"),
-                   control = list(),
-                   subset, weights, na.action, offset,
-                   model = TRUE, x = FALSE, y = FALSE,...)
-      {
-          nCall <- mCall <- match.call()
-          cov <- formula[[3]]
-          grps <- getGroupsFormula(data)[[2]]
-          nCall$random <- eval(substitute(~ cov | grps))
-          .Call("nlme_replaceSlot", eval(nCall, parent.frame()), "call",
-                mCall, PACKAGE = "Matrix")
-      })
 
 setMethod("lme", signature(random = "formula"),
           function(formula, data, random,
@@ -137,19 +122,6 @@ setMethod("lme", signature(random = "formula"),
                 mCall, PACKAGE = "Matrix")
       })
 
-setMethod("lme", signature(formula = "formula", data = "groupedData",
-                           random = "list"),
-          function(formula, data, random,
-                   method = c("REML", "ML"),
-                   control = list(),
-                   subset, weights, na.action, offset,
-                   model = TRUE, x = FALSE, y = FALSE,...)
-      {
-          nCall <- mCall <- match.call()
-          nCall$data <- data@data
-          .Call("nlme_replaceSlot", eval(nCall, parent.frame()), "call",
-                mCall, PACKAGE = "Matrix")
-      })
           
 setMethod("lme", signature(formula = "formula",
                            random = "list"),
@@ -493,21 +465,6 @@ setMethod("lme1", signature(formula = "missing"),
                 mCall, PACKAGE = "Matrix")
       })
 
-setMethod("lme1", signature(formula = "formula", data = "groupedData",
-                           random = "missing"),
-          function(formula, data, random,
-                   method = c("REML", "ML"),
-                   control = list(),
-                   subset, weights, na.action, offset,
-                   model = TRUE, x = FALSE, y = FALSE,...)
-      {
-          nCall = mCall = match.call()
-          cov = formula[[3]]
-          grps = getGroupsFormula(data)[[2]]
-          nCall$random = eval(substitute(~ cov | grps))
-          .Call("nlme_replaceSlot", eval(nCall, parent.frame()), "call",
-                mCall, PACKAGE = "Matrix")
-      })
 
 setMethod("lme1", signature(random = "formula"),
           function(formula, data, random,
@@ -526,19 +483,6 @@ setMethod("lme1", signature(random = "formula"),
                 mCall, PACKAGE = "Matrix")
       })
 
-setMethod("lme1", signature(formula = "formula", data = "groupedData",
-                           random = "list"),
-          function(formula, data, random,
-                   method = c("REML", "ML"),
-                   control = list(),
-                   subset, weights, na.action, offset,
-                   model = TRUE, x = FALSE, y = FALSE,...)
-      {
-          nCall <- mCall <- match.call()
-          nCall$data <- data@data
-          .Call("nlme_replaceSlot", eval(nCall, parent.frame()), "call",
-                mCall, PACKAGE = "Matrix")
-      })
           
 setMethod("lme1", signature(formula = "formula",
                            random = "list"),
@@ -577,6 +521,7 @@ setMethod("lme1", signature(formula = "formula",
                 controlvals$EMverbose,
                 PACKAGE = "Matrix")
           LMEoptimize(obj) <- controlvals
+          obj@call <- match.call()
           #fitted = .Call("ssclme_fitted", obj, facs, mmats, TRUE, PACKAGE = "Matrix")
           #residuals = mmats$.Xy[,".response"] - fitted
           #if (as.logical(x)[1]) x = mmats else x = list()
@@ -584,188 +529,4 @@ setMethod("lme1", signature(formula = "formula",
           obj
       })
 
-setReplaceMethod("LMEoptimize", signature(x="lmeRep", value="list"),
-                 function(x, value)
-             {
-                 if (value$msMaxIter < 1) return(x)
-                 st = coef(x, unconst = TRUE) # starting values
-                 if (value$optimizer == "optim") {
-                     optimRes =
-                         if (value$analyticGradient) {
-                             optim(st,
-                                   fn = function(pars) {
-                                       coef(x, unconst = TRUE) = pars
-                                       deviance(x, REML = value$REML)
-                                   },
-                                   gr = function(pars) {
-                                       coef(x, unconst = TRUE) = pars
-                                       gradient(x, REML = value$REML,
-                                                unconst = TRUE)
-                                   },
-                                   method = "BFGS",
-                                   control = list(trace = value$msVerbose,
-                                                  reltol = value$msTol,
-                                                  maxit = value$msMaxIter))
-                         } else {
-                             optim(st,
-                                   fn = function(pars) {
-                                       coef(x, unconst = TRUE) = pars
-                                       deviance(x, REML = value$REML)
-                                   },
-                                   method = "BFGS",
-                                   control = list(trace = value$msVerbose,
-                                                  reltol = value$msTol,
-                                                  maxit = value$msMaxIter))
-                         }
-                     if (optimRes$convergence != 0) {
-                         warning("optim failed to converge")
-                     }
-                     coef(x, unconst = TRUE) = optimRes$par
-                 } else {
-                     typsize <- rep(1.0, length(st))
-                     if (is.null(value$nlmStepMax))
-                         value$nlmStepMax <-
-                             max(100 * sqrt(sum((st/typsize)^2)), 100)
-                     nlmRes =
-                         nlm(f = if (value$analyticGradient) {
-                             function(pars) {
-                                 coef(x, unconst = TRUE) = pars
-                                 ans = deviance(x, REML = value$REML)
-                                 attr(ans, "gradient") =
-                                     gradient(x, REML = value$REML,
-                                              unconst = TRUE)
-                                 ans
-                             }
-                         } else {
-                             function(pars)
-                             {
-                                 coef(x, unconst = TRUE) = pars
-                                 deviance(x, REML = value$REML)
-                             }
-                         },
-                             p = st,
-                             print.level = if (value$msVerbose) 2 else 0,
-                             steptol = value$msTol,
-                             gradtol = value$msTol,
-                             stepmax = value$nlmStepMax,
-                             typsize=typsize,
-                             iterlim = value$msMaxIter)
-                     coef(x, unconst = TRUE) = nlmRes$estimate
-                 }
-                 return(x)
-             })
 
-setMethod("deviance", signature(object = "lmeRep"),
-          function(object, REML = FALSE, ...) {
-              .Call("lmeRep_factor", object, PACKAGE = "Matrix")
-              object@deviance[ifelse(REML, 2, 1)]
-          })
-
-setMethod("ranef", signature(object = "lmeRep"),
-          function(object, ...) {
-              .Call("lmeRep_ranef", object, PACKAGE = "Matrix")
-          })
-
-setMethod("fixef", signature(object = "lmeRep"),
-          function(object, ...) {
-              val = .Call("lmeRep_fixef", object, PACKAGE = "Matrix")
-              names(val) = object@cnames[[".fixed"]]
-              val[-length(val)]
-          })
-
-setMethod("vcov", signature(object = "lmeRep"),
-          function(object, REML = TRUE, useScale = TRUE,...) {
-              ## force an "lmeRep_invert"
-              sc <- .Call("lmeRep_sigma", object, REML, PACKAGE = "Matrix")
-              rr <- object@RXX
-              nms <- object@cnames[[".fixed"]]
-              dimnames(rr) <- list(nms, nms)
-              nr <- nrow(rr)
-              rr <- rr[-nr, -nr, drop = FALSE]
-              rr <- rr %*% t(rr)
-              if (useScale) {
-                  rr = sc^2 * rr
-              }
-              rr
-          })
-
-setMethod("VarCorr", signature(x = "lmeRep"),
-          function(x, REML = TRUE, useScale = TRUE, ...) {
-              val = .Call("lmeRep_variances", x, PACKAGE = "Matrix")
-              for (i in seq(along = val)) {
-                  dimnames(val[[i]]) = list(x@cnames[[i]], x@cnames[[i]])
-                  val[[i]] = as(as(val[[i]], "pdmatrix"), "corrmatrix")
-              }
-              new("VarCorr",
-                  scale = .Call("lmeRep_sigma", x, REML),
-                  reSumry = val,
-                  useScale = useScale)
-          })
-
-setMethod("gradient", signature(x = "lmeRep"),
-          function(x, REML, unconst, ...)
-          .Call("lmeRep_gradient", x, REML, unconst))
-
-setMethod("summary", "lmeRep",
-          function(object, REML = TRUE, useScale = TRUE, ...) {
-              fcoef <- fixef(object)
-              corF <- as(as(vcov(object, REML, useScale), "pdmatrix"),
-                         "corrmatrix")
-              DF <- getFixDF(object)
-              coefs <- cbind(fcoef, corF@stdDev, DF)
-              nc <- object@nc
-              dimnames(coefs) <-
-                  list(names(fcoef), c("Estimate", "Std. Error", "DF"))
-              new("summary.ssclme",
-                  coefficients = as.matrix(coefs),
-                  scale = .Call("lmeRep_sigma", object, REML),
-                  denomDF = as.integer(DF),
-                  REML = REML,
-                  ngrps = unlist(lapply(object@levels, length)),
-                  nobs = nc[length(nc)],
-                  corFixed = corF,
-                  VarCorr = VarCorr(object, REML, useScale),
-                  useScale = useScale,
-                  showCorrelation = FALSE)
-          })
-
-## calculates degrees of freedom for fixed effects Wald tests
-## This is a placeholder.  The answers are generally wrong.  It will
-## be very tricky to decide what a 'right' answer should be with
-## crossed random effects.
-
-setMethod("getFixDF", signature(object="lmeRep"),
-          function(object, ...)
-      {
-          nc <- object@nc[-seq(along = object@Omega)]
-          p <- nc[1] - 1
-          n <- nc[2]
-          rep(n-p, p)
-      })
-
-setMethod("anova", signature(object="lmeRep"),
-          function(object, ...)
-      {
-          foo <- object
-          foo@status["factored"] <- FALSE
-          .Call("lmeRep_factor", foo, PACKAGE="Matrix")
-          dfr <- getFixDF(foo)
-          ss <- foo@RXX[ , ".response"]^2
-          ssr <- ss[[".response"]]
-          ss <- ss[seq(along = dfr)]
-          names(ss) <- object@cnames[[".fixed"]][seq(along = dfr)]
-          # FIXME: This only gives single degree of freedom tests
-          ms <- ss
-          df <- rep(1, length(ms))
-          f <- ms/(ssr/dfr)
-          P <- pf(f, df, dfr, lower.tail = FALSE)
-          table <- data.frame(df, ss, ms, dfr, f, P)
-          dimnames(table) <-
-              list(names(ss),
-                   c("Df", "Sum Sq", "Mean Sq", "Denom", "F value", "Pr(>F)"))
-          if (any(match(names(ss), "(Intercept)", nomatch = 0)))
-              table <- table[-1,]
-          attr(table, "heading") <- "Analysis of Variance Table"
-          class(table) <- c("anova", "data.frame")
-          table
-      })
